eqcorrscan.core.match\_filter.matched\_filter.match\_filter
===========================================================

.. currentmodule:: eqcorrscan.core.match_filter.matched_filter

.. autofunction:: match_filter